@@ -56,10 +56,6 @@ def tensor(data, dtype=None):
         return nd.array(data, dtype=dtype)
 
 def as_scalar(data):
-    if data.size != 1:
-        raise ValueError("The current array is not a scalar")
-    if data.shape != (1,):
-        data = data.expand_dims(axis=0)
     return data.asscalar()
 
 def get_preferred_sparse_format():
@@ -149,15 +145,9 @@ def sum(input, dim, keepdims=False):
         return nd.array([0.], dtype=input.dtype, ctx=input.context)
     return nd.sum(input, axis=dim, keepdims=keepdims)
 
-def floor_div(in1, in2):
-    return in1 / in2
-
 def reduce_sum(input):
     return input.sum()
 
-def cumsum(input, dim):
-    return nd.cumsum(input, axis=dim)
-
 def mean(input, dim):
     return nd.mean(input, axis=dim)
 
@@ -365,11 +355,11 @@ def sort_1d(input):
     idx = nd.cast(idx, dtype='int64')
     return val, idx
 
-def arange(start, stop, dtype=np.int64, ctx=None):
+def arange(start, stop, dtype=np.int64):
     if start >= stop:
-        return nd.array([], dtype=dtype, ctx=ctx)
+        return nd.array([], dtype=dtype)
     else:
-        return nd.arange(start, stop, dtype=dtype, ctx=ctx)
+        return nd.arange(start, stop, dtype=dtype)
 
 def rand_shuffle(arr):
     return mx.nd.random.shuffle(arr)
